# Eliza
[![PyPI](https://img.shields.io/pypi/v/Eliza.svg?maxAge=2592000)]()

As we write micro-services, we write micro-tools and as a consequence we end up with multiple small ones.

Nevertheless we want to have a consistent look and feel, without bothering to write/provide the same functionality/resources.

This library is targeted specifically to developers who want to create lightweight web-based tools based on python and flask.

It provides functions that all our tools share (or should share) so that the tool itself can concentrate on its main function and become even smaller.

## Why the name Eliza?
Eliza Smith Edison (born 19. May 1844) is a sister of Thomas Edison and this project is part of a "sister" project of the [Edison Microservice](https://github.com/otto-de/edison-microservice).
